@@ -35,6 +35,7 @@ from .property import (
 
 SITE_TYPES_RESTRICTED = [
     SiteSiteType.CROPLAND.value,
+    SiteSiteType.GLASS_OR_HIGH_ACCESSIBLE_COVER.value,
     SiteSiteType.PERMANENT_PASTURE.value
 ]
 PRODUCTS_MODEL_CONFIG = {
@@ -193,7 +194,7 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_linked_source_privacy(cycle, 'defaultSource', node_map),
         validate_private_has_source(cycle, 'defaultSource'),
         validate_cycleDuration(cycle) if _should_validate_cycleDuration(cycle) else True,
-        validate_dataCompleteness(cycle.get('dataCompleteness', {}), site) if 'dataCompleteness' in cycle else True,
+        validate_dataCompleteness(cycle, site) if 'dataCompleteness' in cycle else True,
         validate_siteDuration(cycle),
         validate_otherSites_cycleDuration(cycle),
         validate_possibleCoverCrop(cycle)
