@@ -7,7 +7,7 @@ from .shared import (
     validate_list_term_percent, validate_linked_source_privacy, validate_date_lt_today,
     validate_list_model, validate_private_has_source, validate_list_value_between_min_max
 )
-from .indicator import validate_characterisedIndicator_model
+from .indicator import validate_characterisedIndicator_model, validate_landTransformation
 
 
 def validate_linked_cycle_product(impact_assessment: dict, cycle: dict):
@@ -64,5 +64,6 @@ def validate_impact_assessment(impact_assessment: dict, node_map: dict = {}):
         validate_list_min_below_max(impact_assessment, 'emissionsResourceUse'),
         validate_list_value_between_min_max(impact_assessment, 'emissionsResourceUse'),
         validate_list_term_percent(impact_assessment, 'emissionsResourceUse'),
-        validate_characterisedIndicator_model(impact_assessment, 'emissionsResourceUse')
+        validate_characterisedIndicator_model(impact_assessment, 'emissionsResourceUse'),
+        validate_landTransformation(impact_assessment, 'emissionsResourceUse')
     ] if 'emissionsResourceUse' in impact_assessment else [])
