@@ -112,6 +112,15 @@ def validate_depths(measurements: list):
 
 
 def validate_required_depths(site: dict, list_key: str):
+    values = site.get(list_key, [])
+    has_depths = any(filter(
+        lambda v: v.get('term', {}).get('@id') in SOIL_TEXTURE_IDS and (
+            v.get('depthUpper') or v.get('depthLower')
+        ),
+        values
+    ))
+    level = 'error' if has_depths else 'warning'
+
     def validate(values: tuple):
         index, measurement = values
         term = measurement.get('term', {})
@@ -121,12 +130,12 @@ def validate_required_depths(site: dict, list_key: str):
         with_depth = get_table_value(lookup, 'termid', term_id, column_name('recommendAddingDepth'))
         has_depths = measurement.get('depthUpper') is not None and measurement.get('depthLower') is not None
         return not with_depth or with_depth == '' or has_depths or {
-            'level': 'warning',
+            'level': level,
             'dataPath': f".{list_key}[{index}]",
             'message': 'should set both depthUpper and depthLower'
         }
 
-    return _filter_list_errors(map(validate, enumerate(site.get(list_key, []))))
+    return _filter_list_errors(map(validate, enumerate(values)))
 
 
 def validate_term_unique(measurements: list):
