@@ -1,7 +1,7 @@
 from hestia_earth.schema import TermTermType
 from hestia_earth.utils.model import find_primary_product
 from hestia_earth.utils.lookup import get_table_value, download_lookup, column_name
-from hestia_earth.utils.tools import list_sum, flatten
+from hestia_earth.utils.tools import list_sum, flatten, non_empty_list
 
 from hestia_earth.validation.utils import _list_sum, _filter_list_errors
 
@@ -72,31 +72,55 @@ def validate_primary(products: list):
     }
 
 
-def _get_excreta_term(cycle: dict):
-    product = find_primary_product(cycle) or {}
-    term_id = product.get('term', {}).get('@id')
-    term_type = product.get('term', {}).get('termType')
-    lookup = download_lookup(f"{term_type}.csv")
-    return product, get_table_value(lookup, 'termid', term_id, column_name('excretaKgNTermId'))
+def _get_excreta_term(lookup, product_id: str, column: str):
+    value = get_table_value(lookup, 'termid', product_id, column_name(column))
+    return non_empty_list((value or '').split(';'))
+
+
+UNITS_TO_EXCRETA_LOOKUP = {
+    'kg': ['allowedExcretaKgMassTermIds', 'recommendedExcretaKgMassTermIds'],
+    'kg N': ['allowedExcretaKgNTermIds', 'recommendedExcretaKgNTermIds'],
+    'kg VS': ['allowedExcretaKgVsTermIds', 'recommendedExcretaKgVsTermIds']
+}
 
 
 def validate_excreta(cycle: dict, list_key: str = 'products'):
-    primary_product, excreta = _get_excreta_term(cycle)
+    primary_product = find_primary_product(cycle) or {}
+    product_term_id = primary_product.get('term', {}).get('@id')
+    lookup = download_lookup(f"{primary_product.get('term', {}).get('termType')}.csv")
 
     def validate(values: tuple):
         index, product = values
         term_id = product.get('term', {}).get('@id')
         term_type = product.get('term', {}).get('termType')
-        return term_type != TermTermType.EXCRETA.value or term_id == excreta or {
-            'level': 'warning',
-            'dataPath': f".{list_key}[{index}].term.@id",
-            'message': 'is too generic',
-            'params': {
-                'product': primary_product.get('term'),
-                'term': product.get('term', {}),
-                'current': term_id,
-                'expected': excreta
+        term_units = product.get('term', {}).get('units')
+        allowed_column, recommended_column = UNITS_TO_EXCRETA_LOOKUP.get(term_units, [None, None])
+        allowed_ids = _get_excreta_term(lookup, product_term_id, allowed_column)
+        recommended_ids = _get_excreta_term(lookup, product_term_id, recommended_column)
+        return term_type != TermTermType.EXCRETA.value or (
+            len(allowed_ids) != 0 and term_id not in allowed_ids and {
+                'level': 'error',
+                'dataPath': f".{list_key}[{index}].term.@id",
+                'message': 'is too generic',
+                'params': {
+                    'product': primary_product.get('term'),
+                    'term': product.get('term', {}),
+                    'current': term_id,
+                    'expected': allowed_ids
+                }
             }
-        }
+        ) or (
+            len(recommended_ids) != 0 and term_id not in recommended_ids and {
+                'level': 'warning',
+                'dataPath': f".{list_key}[{index}].term.@id",
+                'message': 'is too generic',
+                'params': {
+                    'product': primary_product.get('term'),
+                    'term': product.get('term', {}),
+                    'current': term_id,
+                    'expected': recommended_ids
+                }
+            }
+        ) or True
 
-    return not excreta or _filter_list_errors(map(validate, enumerate(cycle.get(list_key, []))))
+    return _filter_list_errors(map(validate, enumerate(cycle.get(list_key, []))))
