@@ -3,16 +3,17 @@ from hestia_earth.utils.tools import flatten
 
 from hestia_earth.validation.gee import fetch_data
 from .shared import (
-    validate_dates, validate_list_dates, validate_list_dates_format, validate_list_min_max,
+    validate_dates, validate_list_dates, validate_list_dates_format, validate_list_min_below_max,
+    validate_list_min_max_lookup,
     validate_region_in_country, validate_country, validate_is_region, validate_coordinates, need_validate_coordinates,
     validate_area, need_validate_area, validate_list_term_percent, validate_linked_source_privacy,
     validate_list_date_lt_today, validate_date_lt_today, validate_area_size,
     validate_region_size, need_validate_region_size, validate_boundary_size, need_validate_boundary_size,
-    validate_private_has_source
+    validate_private_has_source, validate_list_value_between_min_max
 )
 from .infrastructure import validate_lifespan
 from .measurement import (
-    validate_soilTexture, validate_depths, validate_required_depths, validate_value_min_max, validate_term_unique,
+    validate_soilTexture, validate_depths, validate_required_depths, validate_term_unique,
     validate_require_startDate_endDate, validate_with_models, validate_value_length
 )
 from .practice import (
@@ -113,12 +114,15 @@ def validate_site(site: dict, node_map: dict = {}):
         validate_list_dates(site, 'measurements'),
         validate_list_dates_format(site, 'measurements'),
         validate_list_date_lt_today(site, 'measurements', ['startDate', 'endDate']),
-        validate_list_min_max(site, 'measurements'),
+        validate_list_min_below_max(site, 'measurements'),
+        validate_list_value_between_min_max(site, 'measurements'),
+        validate_list_min_max_lookup(site, 'measurements', 'value'),
+        validate_list_min_max_lookup(site, 'measurements', 'min'),
+        validate_list_min_max_lookup(site, 'measurements', 'max'),
         validate_list_term_percent(site, 'measurements'),
         validate_soilTexture(site.get('measurements')),
         validate_depths(site.get('measurements')),
         validate_required_depths(site, 'measurements'),
-        validate_value_min_max(site.get('measurements')),
         validate_term_unique(site.get('measurements')),
         validate_properties_default_value(site, 'measurements'),
         validate_properties_valueType(site, 'measurements'),
@@ -134,7 +138,8 @@ def validate_site(site: dict, node_map: dict = {}):
         validate_list_dates(site, 'practices'),
         validate_list_dates_format(site, 'practices'),
         validate_list_date_lt_today(site, 'practices', ['startDate', 'endDate']),
-        validate_list_min_max(site, 'practices'),
+        validate_list_min_below_max(site, 'practices'),
+        validate_list_value_between_min_max(site, 'practices'),
         validate_list_term_percent(site, 'practices'),
         validate_cropResidueManagement(site.get('practices')),
         validate_longFallowPeriod(site.get('practices')),
