@@ -288,15 +288,18 @@ def test_validate_required_depths_valid():
 def test_validate_required_depths_warning():
     with open(f"{fixtures_path}/measurement/required-depths/warning.json") as f:
         data = json.load(f)
-    assert validate_required_depths(data, 'measurements') == [
-        {
-            'level': 'warning',
-            'dataPath': '.measurements[3]',
-            'message': 'should set both depthUpper and depthLower'
-        },
-        {
-            'level': 'warning',
-            'dataPath': '.measurements[7]',
-            'message': 'should set both depthUpper and depthLower'
-        }
-    ]
+    assert validate_required_depths(data, 'measurements') == {
+        'level': 'warning',
+        'dataPath': '.measurements[0]',
+        'message': 'should set both depthUpper and depthLower'
+    }
+
+
+def test_validate_required_depths_error():
+    with open(f"{fixtures_path}/measurement/required-depths/error.json") as f:
+        data = json.load(f)
+    assert validate_required_depths(data, 'measurements') == {
+        'level': 'error',
+        'dataPath': '.measurements[3]',
+        'message': 'should set both depthUpper and depthLower'
+    }
